.. image:: ../../_static/CSAwesomeLogo.png
    :width: 350
    :align: center

Recursion
:::::::::

Class Periods: 3-5

AP CSA Exam Weighting: 5-7.5%

.. toctree::
   :maxdepth: 3

   topic-10-1-recursion.rst
   topic-10-2-recursive-search-sort.rst
   summary.rst
   rParsonsPractice.rst
   rMixedUpCodePractice.rst
   topic-10-4-toggle-problems.rst
   recursionCodePractice.rst
   Exercises.rst

